package libreoffice_test

import (
	"encoding/base64"
	"io/ioutil"
	"strings"
	"testing"

	"github.com/stretchr/testify/require"

	"orus.io/orus-io/rednerd/models"
	"orus.io/orus-io/rednerd/tests"
)

func writeOutFile(t *testing.T, d models.Document, ext string) {
	t.Helper()

	b, err := d.Bytes()
	require.NoError(t, err)
	name := strings.ReplaceAll(t.Name(), "/", "_") + ext
	require.NoError(t, ioutil.WriteFile(name, b, 0o600))
}

func TestConvert(t *testing.T) {
	tester := tests.NewAPITester(t, nil)
	defer tester.Close()

	defer tester.Logout()
	tester.Login("admin", "admin")

	basicsOdtBytes, err := ioutil.ReadFile("../../dependencies/od-templating/examples/basics.odt")
	require.NoError(t, err)

	for _, tt := range []struct {
		mimetype string
		ext      string
	}{
		{"application/pdf", "pdf"},
		{"application/msword", "docx"},
		{"text/html", "html"},
		{"text/plain", "txt"},
	} {
		t.Run("odt-to-"+tt.ext, func(t *testing.T) {
			defer tester.SetT(t)()

			var result []models.Document
			tester.MustPostJSON(
				"/api/v1/render",
				tests.JSONObj{
					"accept": tt.mimetype,
					"document": tests.JSONObj{
						"type":        "application/vnd.oasis.opendocument.text",
						"body-format": "base64",
						"body":        base64.StdEncoding.EncodeToString(basicsOdtBytes),
					},
				},
				&result,
			)
			require.Equal(t, 1, len(result))
			writeOutFile(t, result[0], "."+tt.ext)
		})
	}
}
