package models

import (
	"database/sql"
	"time"

	"github.com/jackc/pgtype"
	"orus.io/orus-io/go-orusapi/database"
)

// dbtable:"render_logs" dbpkey:"id"
type RenderLog struct {
	ID                      int64          `db:"id"`
	RenderedAt              time.Time      `db:"rendered_at"`
	Duration                int            `db:"duration"`
	FromType                string         `db:"from_type"`
	ToType                  string         `db:"to_type"`
	Username                string         `db:"username"`
	PipelineSteps           pgtype.JSONB   `db:"pipeline_steps"`
	TemplateID              sql.NullInt64  `db:"template_id"`
	TemplateInternalVersion sql.NullInt64  `db:"template_internal_version"`
	TemplateLanguage        sql.NullString `db:"template_language"`
}

func NewRenderLog(
	when time.Time, duration time.Duration,
	fromType, toType string,
	username string,
	templateID, templateInternalVersion uint64,
	templateLanguage string,
) *RenderLog {
	rlog := RenderLog{
		RenderedAt: when,
		Duration:   int(duration / time.Millisecond),
		FromType:   fromType,
		ToType:     toType,
		Username:   username,
	}
	if templateID != 0 {
		rlog.TemplateID.Int64 = int64(templateID)
		rlog.TemplateID.Valid = true
	}
	if templateInternalVersion != 0 {
		rlog.TemplateInternalVersion.Int64 = int64(templateInternalVersion)
		rlog.TemplateInternalVersion.Valid = true
	}
	if templateLanguage != "" {
		rlog.TemplateLanguage.String = templateLanguage
		rlog.TemplateLanguage.Valid = true
	}

	_ = rlog.PipelineSteps.Set(map[string]string{})

	return &rlog
}

func LogRender(
	db database.SQLHelper,
	when time.Time, duration time.Duration,
	fromType, toType string,
	username string,
	templateID, templateInternalVersion uint64,
	templateLanguage string,
) error {
	rlog := NewRenderLog(
		when, duration, fromType, toType, username, templateID, templateInternalVersion, templateLanguage,
	)
	if _, err := db.InsertNoPKey(rlog); err != nil {
		return err
	}

	return nil
}
