package tests

import (
	"context"
	"testing"

	"github.com/Masterminds/squirrel"
	"github.com/stretchr/testify/assert"
	"github.com/stretchr/testify/require"
	"orus.io/orus-io/go-orusapi/database"

	"orus.io/orus-io/rednerd/models"
	"orus.io/orus-io/rednerd/testutils"
)

func TestForgotPassword(t *testing.T) {
	tester := NewAPITester(t, nil)
	defer tester.Close()

	if !assert.Equal(t, 204, tester.MustPostJSON("/api/v1/auth/register", JSONObj{
		"username":  "",
		"firstname": "Annie",
		"lastname":  "Ernaux",
		"email":     "example@example.com",
		"is-admin":  true,
	}, nil)) {
		t.FailNow()
	}

	if !assert.Equal(t, 204, tester.MustPostJSON("/api/v1/auth/forgot-password", JSONObj{
		"username": "",
		"email":    "example@example.com",
		"is-admin": true,
	}, nil)) {
		t.FailNow()
	}

	db := database.NewSQLHelper(context.Background(), tester.DB, testutils.GetLogger(t))
	var entry models.ResetPasswordTokenDB
	require.NoError(t, db.Get(
		&entry, squirrel.Select("*").From("reset_password_token").
			Where(squirrel.Eq{"username": "example@example.com"}),
	))
}
